==> kaolinite-0.3.0.crate: kaolinite-0.3.0/.todo.md <==
- [ ] File buffering
- [ ] Add synoptic feature
- [ ] Thorough documentation
- [ ] Thorough testing
- [ ] Add undo / redo feature
- [ ] Thorough documentation 
- [ ] Thorough testing 
- [ ] Add searching feature 
- [ ] Thorough documentation 
- [ ] Thorough testing 
- [ ] Add several formatting tools
  - [ ] Status line formatting 
  - [ ] Line number formatting 
- [ ] Fix any bugs
- [ ] Add more examples
- [ ] Release 1.0.0
- [ ] Use ropey 
- [X] Skeleton code
- [X] Basic modification
- [X] Handle \r\n and \n
- [X] Set up enums
- [X] Link up status for Row
- [X] Link up status for Document
- [X] Ablility to partially render rows
- [X] Function to return word delimeters
- [X] Add modified flag on rows
- [X] Add cursor
- [X] Add offset
- [X] Unicode safe movement
  - [X] Traversing left & right
    - [X] Left
    - [X] Right
  - [X] Traversing up & down
    - [X] Up
    - [X] Down
- [X] Make sure non-existent last row sets x to (0, 0)
- [X] Make sure that when moving up and down, cursor is snapped to the end of the line
- [X] Add in save capability
- [X] Add in save as capability
- [X] Write readme
- [X] Update cargo.toml
- [X] Handle tabs & spaces
- [X] Implement row splitting
- [X] Goto x & y
  - [X] x
  - [X] y
- [X] Add event execution system to document
- [X] Add in modified field to document
- [X] Rustfmt
- [X] Ensure 100% test coverage
- [X] Ensure good documentation
  - [X] document
  - [X] event
  - [X] Add global crate documentation
  - [X] row
  - [X] utils
- [X] Remove thiserror
- [X] Lazy regex into lazy static and regex
- [X] Clippy & Rustfmt & Tarp
- [X] Release 0.1.0
- [X] Write a changelog [0.1.1]
- [X] Optimise Row::width [0.1.3]
- [X] Optimise Row::split [0.1.4]
- [X] Optimise Row::splice [0.1.5]
- [X] Optimise Row::remove [0.2.0]
- [X] Optimise Row::link [0.2.1]
- [X] Filetype determination 
- [X] Build demonstration editor 
  - [X] Change API to make more convenient

==> kaolinite-0.4.0.crate: kaolinite-0.4.0/.todo.md <==
- [ ] Add undo / redo feature
- [ ] Thorough documentation 
- [ ] Thorough testing 
- [ ] Add searching feature 
- [ ] Thorough documentation 
- [ ] Thorough testing 
- [ ] Fix any bugs
- [ ] Add more examples
- [ ] File buffering
- [ ] Use ropey 
- [ ] Release 1.0.0
- [X] Skeleton code
- [X] Basic modification
- [X] Handle \r\n and \n
- [X] Set up enums
- [X] Link up status for Row
- [X] Link up status for Document
- [X] Ablility to partially render rows
- [X] Function to return word delimeters
- [X] Add modified flag on rows
- [X] Add cursor
- [X] Add offset
- [X] Unicode safe movement
  - [X] Traversing left & right
    - [X] Left
    - [X] Right
  - [X] Traversing up & down
    - [X] Up
    - [X] Down
- [X] Make sure non-existent last row sets x to (0, 0)
- [X] Make sure that when moving up and down, cursor is snapped to the end of the line
- [X] Add in save capability
- [X] Add in save as capability
- [X] Write readme
- [X] Update cargo.toml
- [X] Handle tabs & spaces
- [X] Implement row splitting
- [X] Goto x & y
  - [X] x
  - [X] y
- [X] Add event execution system to document
- [X] Add in modified field to document
- [X] Rustfmt
- [X] Ensure 100% test coverage
- [X] Ensure good documentation
  - [X] document
  - [X] event
  - [X] Add global crate documentation
  - [X] row
  - [X] utils
- [X] Remove thiserror
- [X] Lazy regex into lazy static and regex
- [X] Clippy & Rustfmt & Tarp
- [X] Release 0.1.0
- [X] Write a changelog [0.1.1]
- [X] Optimise Row::width [0.1.3]
- [X] Optimise Row::split [0.1.4]
- [X] Optimise Row::splice [0.1.5]
- [X] Optimise Row::remove [0.2.0]
- [X] Optimise Row::link [0.2.1]
- [X] Filetype determination 
- [X] Build demonstration editor 
  - [X] Change API to make more convenient
- [X] Add several formatting tools
  - [X] Status line formatting 
  - [X] Line number formatting
